@@ -1,5 +1,6 @@
-from CustomModel import * # seq2seq module
-from Utils import * # other functions
+from . import CustomModel # seq2seq module
+from . import Utils # other functions
+from Utils import *
 
 def model_only(sentence):
   text = spacer(sentence)
